/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: inc.h,v 1.24 2006/09/26 18:12:20 bowkenken Exp $
***************************************************************/

#ifndef	INC_H
#define	INC_H

/***************************************************************
* 󥯥롼ɡꥹ
***************************************************************/

#ifdef	AMENU_C

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
#include	"item.h"
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
#include	"amenu.h"
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
#include	"amenu-prot.h"
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
#include	"msg-prot.h"

#endif	/* AMENU_C */

/***************************************************************/

#ifdef	CHR_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
#include	"town.h"
#include	"item.h"
#include	"spell.h"
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
#include	"amenu.h"
#include	"request.h"
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
#include	"amenu-prot.h"
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* CHR_C */

/***************************************************************/

#ifdef	CURS_C

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"call-prot.h"

# ifdef	D_DOS
#  include	<windows.h>
#  include	<conio.h>
#  ifdef	D_WIN
#   include	"../lnl-dos/stdafx.h"
#  else
#   include	"lnl-dos/stdafx.h"
#  endif
# endif

#endif	/* CURS_C */

/***************************************************************/

#ifdef	DRAW_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
#include	"town.h"
/*#include	"item.h"*/
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
#include	"gfile.h"
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
#include	"tmenu-prot.h"
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
#include	"gfile-prot.h"
#include	"msg-prot.h"

#include	"call-prot.h"

#include	"vfx-kind.h"

# ifdef	D_X68K
#  include	<doslib.h>
# endif

# ifdef	D_DOS
#  include	<conio.h>
# endif

#endif	/* DRAW_C */

/***************************************************************/

#ifdef	DUN_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
#include	"dun.h"
#include	"town.h"
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
/*#include	"amenu.h"*/
#include	"request.h"
#include	"gfile.h"
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
#include	"gfile-prot.h"
/*#include	"msg-prot.h"*/

#include	"nest-flg.h"
#include	"nest-flg-prot.h"

#include	"call-prot.h"

#endif	/* DUN_C */

/***************************************************************/

#ifdef	FIGHT_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
#include	"party.h"
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
#include	"fight.h"
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
/*#include	"pet-prot.h"*/
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* FIGHT_C */

/***************************************************************/

#ifdef	FX_C

#include	"gmain.h"
/*#include	"misc.h"*/
#include	"turn.h"
/*#include	"dun.h"*/
/*#include	"town.h"*/
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
#include	"party.h"
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
#include	"msg-prot.h"

#endif	/* FX_C */

/***************************************************************/

#ifdef	GFILE_C

#include	"gmain.h"
/*#include	"misc.h"*/
#include	"turn.h"
#include	"town.h"
#include	"item.h"
#include	"spell.h"
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
#include	"amenu.h"
#include	"request.h"
#include	"gfile.h"
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
#include	"amenu-prot.h"
#include	"request-prot.h"
#include	"gfile-prot.h"
#include	"msg-prot.h"

#endif	/* GFILE_C */

/***************************************************************/

#ifdef	GMAIN_C

#include	"gmain.h"
#include	"misc.h"
#include	"turn.h"
#include	"town.h"
#include	"item.h"
#include	"spell.h"
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
#include	"fight.h"
#include	"fx.h"
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
#include	"amenu.h"
#include	"request.h"
#include	"gfile.h"
#include	"msg.h"
#include	"ver.h"
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
#include	"tmenu-prot.h"
#include	"amenu-prot.h"
#include	"request-prot.h"
#include	"gfile-prot.h"
#include	"msg-prot.h"

#include	<signal.h>

#include	"main-prot.h"

#include	"call-prot.h"

#endif	/* GMAIN_C */

/***************************************************************/

#ifdef	IMENU_C

#include	"gmain.h"
#include	"misc.h"
#include	"turn.h"
#include	"dun.h"
#include	"town.h"
#include	"item.h"
/*#include	"spell.h"*/
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
#include	"gfile.h"
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
#include	"gfile-prot.h"
#include	"msg-prot.h"

#include	"call-prot.h"

#endif	/* IMENU_C */

/***************************************************************/

#ifdef	ITEM_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
#include	"amenu.h"
#include	"request.h"
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
#include	"amenu-prot.h"
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* ITEM_C */

/***************************************************************/

#ifdef	MAIN_DOS_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"misc.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
#include	"ver.h"
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"main-dos-prot.h"

# if	HAVE_GETOPT_H
#  include	<getopt.h>
# endif

#endif	/* MAIN_DOS_C */

/***************************************************************/

#ifdef	MAIN_UNIX_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"misc.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
#include	"ver.h"
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"main-unix-prot.h"

# if	HAVE_GETOPT_H
#  include	<getopt.h>
# endif

# if	HAVE_TERMIOS_H
#  include	<termios.h>
# elif	HAVE_TERMIO_H
#  include	<termio.h>
# endif

# endif	/* MAIN_UNIX_C */

/***************************************************************/

#ifdef	MENU_C

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
#include	"party.h"
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
/*#include	"gmain-prot.h"*/
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
#include	"party-prot.h"
/*#include	"mnstr-prot.h"*/
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"call-prot.h"

#endif	/* MENU_C */

/***************************************************************/

#ifdef	MISC_C

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
#include	"msg-prot.h"

#endif	/* MISC_C */

/***************************************************************/

#ifdef	MMENU_C

#include	"gmain.h"
/*#include	"misc.h"*/
#include	"turn.h"
/*#include	"dun.h"*/
#include	"town.h"
/*#include	"item.h"*/
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
#include	"amenu.h"
/*#include	"request.h"*/
#include	"gfile.h"
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
#include	"tmenu-prot.h"
#include	"amenu-prot.h"
/*#include	"request-prot.h"*/
#include	"gfile-prot.h"
#include	"msg-prot.h"

#include	"call-prot.h"

#endif	/* MMENU_C */

/***************************************************************/

#ifdef	MNSTR_ACT_C

#include	"gmain.h"
#include	"misc.h"
#include	"turn.h"
#include	"dun.h"
#include	"town.h"
#include	"item.h"
/*#include	"spell.h"*/
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
#include	"request.h"
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
/*#include	"gmain-prot.h"*/
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"mnstr-act-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* MNSTR_ACT_C */

/***************************************************************/

#ifdef	MNSTR_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
#include	"request.h"
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* MNSTR_C */

/***************************************************************/

#ifdef	MSG_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
#include	"msg-prot.h"

#endif	/* MSG_C */

/***************************************************************/

#ifdef	PARTY_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
#include	"town.h"
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
#include	"amenu.h"
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
/*#include	"mmenu-prot.h"*/
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
#include	"amenu-prot.h"
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* PARTY_C */

/***************************************************************/

#ifdef	PET_C

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
#include	"dun.h"
/*#include	"town.h"*/
#include	"item.h"
/*#include	"spell.h"*/
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
#include	"trap.h"
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* PET_C */

/***************************************************************/

#ifdef	REQUEST_C

#include	"gmain.h"
#include	"misc.h"
#include	"turn.h"
#include	"dun.h"
/*#include	"town.h"*/
#include	"item.h"
/*#include	"spell.h"*/
#include	"chr.h"
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
/*#include	"amenu.h"*/
#include	"request.h"
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
/*#include	"gmain-prot.h"*/
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
/*#include	"mmenu-prot.h"*/
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* REQUEST_C */

/***************************************************************/

#ifdef	SPELL_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
#include	"msg-prot.h"

#endif	/* SPELL_C */

/***************************************************************/

#ifdef	TMENU_C

#include	"gmain.h"
/*#include	"misc.h"*/
#include	"turn.h"
/*#include	"dun.h"*/
#include	"town.h"
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
#include	"gfile.h"
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
#include	"gfile-prot.h"
/*#include	"msg-prot.h"*/

#endif	/* TMENU_C */

/***************************************************************/

#ifdef	TOWN_C

#include	"gmain.h"
/*#include	"misc.h"*/
#include	"turn.h"
/*#include	"dun.h"*/
#include	"town.h"
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
/*#include	"amenu.h"*/
#include	"request.h"
#include	"gfile.h"
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
#include	"turn-prot.h"
#include	"dun-prot.h"
#include	"town-prot.h"
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
#include	"party-prot.h"
#include	"mnstr-prot.h"
#include	"pet-prot.h"
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
#include	"menu-prot.h"
#include	"mmenu-prot.h"
#include	"imenu-prot.h"
#include	"tmenu-prot.h"
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
#include	"gfile-prot.h"
/*#include	"msg-prot.h"*/

#endif	/* TOWN_C */

/***************************************************************/

#ifdef	TRAP_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
#include	"dun.h"
/*#include	"town.h"*/
#include	"item.h"
#include	"spell.h"
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
#include	"pet.h"
#include	"fight.h"
#include	"fx.h"
#include	"trap.h"
#include	"draw.h"
#include	"curs.h"
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
#include	"dun-prot.h"
/*#include	"town-prot.h"*/
#include	"item-prot.h"
#include	"spell-prot.h"
#include	"chr-prot.h"
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
#include	"pet-prot.h"
#include	"fight-prot.h"
#include	"fx-prot.h"
#include	"trap-prot.h"
#include	"draw-prot.h"
#include	"curs-prot.h"
#include	"menu-prot.h"
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* TRAP_C */

/***************************************************************/

#ifdef	TURN_C

#include	"gmain.h"
#include	"misc.h"
#include	"turn.h"
/*#include	"dun.h"*/
#include	"town.h"
#include	"item.h"
/*#include	"spell.h"*/
/*#include	"chr.h"*/
#include	"party.h"
#include	"mnstr.h"
#include	"pet.h"
/*#include	"fight.h"*/
#include	"fx.h"
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
/*#include	"amenu.h"*/
#include	"request.h"
/*#include	"gfile.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
/*#include	"gmain-prot.h"*/
#include	"misc-prot.h"
#include	"turn-prot.h"
/*#include	"dun-prot.h"*/
#include	"town-prot.h"
#include	"item-prot.h"
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
#include	"mnstr-prot.h"
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
#include	"fx-prot.h"
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
#include	"request-prot.h"
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#endif	/* TURN_C */

/***************************************************************
* xlnl
***************************************************************/

#ifdef	MAIN_X_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
#include	"ver.h"
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"main-x-prot.h"
#include	"call-prot.h"

# if	HAVE_GETOPT_H
#  include	<getopt.h>
# endif

# if	HAVE_TERMIOS_H
#  include	<termios.h>
# elif	HAVE_TERMIO_H
#  include	<termio.h>
# endif

#endif	/* MAIN_X_C */

/***************************************************************/

#ifdef	MAIN_WIN_C

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
#include	"msg.h"
#include	"ver.h"
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	"main-win-prot.h"
#include	"call-prot.h"

# if	HAVE_GETOPT_H
#  include	<getopt.h>
# endif

#endif	/* MAIN_WIN_C */

/***************************************************************/

#ifdef	MAIN_GTK_CPP

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
#include	"menu.h"
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
#include	"imenu-prot.h"
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#include	<gtk/gtk.h>
#include	<gdk-pixbuf/gdk-pixbuf.h>

#include	"main-x-prot.h"
#include	"main-gtk-prot.h"
#include	"call-prot.h"

#include	"MouseMap.h"

#include	"GlobalVar.h"

#endif	/* MAIN_GTK_CPP */

/***************************************************************/

#ifdef	CALL_CPP

# if	defined( D_WS )
#  include <WSDappDev.h>
#  include <WSCwindow.h>
#  include "gmain.h"
#  include "misc.h"
#  include "draw.h"
#  include "GameThread.h"
#  include "GuiMenu.h"
#  include "PcgDun.h"
#  include "GlobalVar.h"
#  include "gmain-prot.h"
#  include "draw-prot.h"
#  include "call-prot.h"
# elif	defined( D_GTK )
#  include "gmain.h"
#  include "misc.h"
#  include "draw.h"
#  include "GameThread.h"
#  include "GuiMenu.h"
#  include "PcgDun.h"
#  include "GlobalVar.h"
#  include "gmain-prot.h"
#  include "draw-prot.h"
#  include "call-prot.h"
# else
#  include "gmain.h"
#  include "misc.h"
#  include "draw.h"
#  include "call-prot.h"
# endif

#endif	/* CALL_CPP */

/***************************************************************/

#ifdef	GUI_MESSAGE_CPP

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
#include	"curs.h"
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
#include	"gmain-prot.h"
/*#include	"misc-prot.h"*/
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
#include	"curs-prot.h"
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
# include <gtk/gtk.h>
# include "GuiMisc.h"
#endif // D_GTK

#endif	/* GUI_MESSAGE_CPP */

/***************************************************************/

#ifdef	GUI_NUM_CPP

#include	"gmain.h"
#include	"misc.h"
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
/*#include	"amenu.h"*/
/*#include	"request.h"*/
/*#include	"gfile.h"*/
/*#include	"msg.h"*/
/*#include	"ver.h"*/
/*#include	"gmain-prot.h"*/
#include	"misc-prot.h"
/*#include	"turn-prot.h"*/
/*#include	"dun-prot.h"*/
/*#include	"town-prot.h"*/
/*#include	"item-prot.h"*/
/*#include	"spell-prot.h"*/
/*#include	"chr-prot.h"*/
/*#include	"party-prot.h"*/
/*#include	"mnstr-prot.h"*/
/*#include	"pet-prot.h"*/
/*#include	"fight-prot.h"*/
/*#include	"fx-prot.h"*/
/*#include	"trap-prot.h"*/
#include	"draw-prot.h"
/*#include	"curs-prot.h"*/
/*#include	"menu-prot.h"*/
/*#include	"mmenu-prot.h"*/
/*#include	"imenu-prot.h"*/
/*#include	"tmenu-prot.h"*/
/*#include	"amenu-prot.h"*/
/*#include	"request-prot.h"*/
/*#include	"gfile-prot.h"*/
/*#include	"msg-prot.h"*/

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
# include <gtk/gtk.h>
# include "GuiMisc.h"
#endif // D_GTK

#endif	/* GUI_NUM_CPP */

/***************************************************************/

#if	defined( D_WIN )
# include	"main-win-prot.h"
#elif	defined( D_DOS )
# include	"main-dos-prot.h"
#else
# include	"main-unix-prot.h"
#endif

/***************************************************************/

#endif	/* INC_H */
